@@ -3,15 +3,20 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-package CairoX;
-
-use Cairo;
-
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
+# PODNAME: CairoX::Sweet
 # ABSTRACT: Wraps Cairo for easier drawing
 
-class Sweet using Moose {
+package CairoX::Sweet;
 
+sub new {
+    shift;
+    CairoX::Sweet::Wrap->new(@_);
+}
+
+class CairoX::Sweet::Wrap using Moose {
+
+    use Cairo;
     use Type::Utils qw/enum/;
     use Types::Path::Tiny qw/AbsPath/;
     use CairoX::Sweet::Color;
@@ -19,7 +24,7 @@ class Sweet using Moose {
     use CairoX::Sweet::Core::CurveTo;
     use CairoX::Sweet::Core::LineTo;
     use CairoX::Sweet::Core::MoveTo;
-    
+
     has surface_format => (
         is => 'ro',
         isa => Str,
@@ -112,7 +117,7 @@ class Sweet using Moose {
 
         $self->c->show_text($text);
         $self->c->fill;
-        
+
     }
 
 }
@@ -125,11 +130,11 @@ __END__
 
 =head1 NAME
 
-CairoX - Wraps Cairo for easier drawing
+CairoX::Sweet - Wraps Cairo for easier drawing
 
 =head1 VERSION
 
-Version 0.0101, released 2015-01-11.
+Version 0.0102, released 2015-01-11.
 
 =head1 SYNOPSIS
 
@@ -234,7 +239,7 @@ Adds a L<CairoX::Sweet::Path> to the C<cairo> object.
 
 C<$path>
 
-The L<CairoX::Sweet::Path> to add. Required. 
+The L<CairoX::Sweet::Path> to add. Required.
 
 C<close => Bool>
 
@@ -245,7 +250,7 @@ on the C<$path> (connects the two end points of the C<$path>).
 
 Adds a string to the C<cairo> object. Takes only named parameters.
 
-    $c->add_text( text => "The text to add", 
+    $c->add_text( text => "The text to add",
                   color => '#444444',
                   x => 37,
                   y => 115,
