@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
 # PODNAME: CairoX::Sweet::Color
-# ABSTRACT: Short intro
+# ABSTRACT:
 
 class CairoX::Sweet::Color using Moose {
 
@@ -21,7 +21,7 @@ class CairoX::Sweet::Color using Moose {
         default => 1,
         isa => NumUpToOne,
     );
-    
+
     method color {
         return ($self->red, $self->green, $self->blue);
     }
@@ -38,11 +38,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Color - Short intro
+CairoX::Sweet::Color - class CairoX::Sweet::Color using Moose {
 
 =head1 VERSION
 
-Version 0.0101, released 2015-01-11.
+Version 0.0102, released 2015-01-11.
 
 =head1 SOURCE
 
