@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
 # PODNAME: CairoX::Sweet::Core::MoveTo
-# ABSTRACT: Short intro
+# ABSTRACT:
 
 class CairoX::Sweet::Core::MoveTo with CairoX::Sweet::Role::PathCommand using Moose {
 
@@ -48,11 +48,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Core::MoveTo - Short intro
+CairoX::Sweet::Core::MoveTo - class CairoX::Sweet::Core::MoveTo with CairoX::Sweet::Role::PathCommand using Moose {
 
 =head1 VERSION
 
-Version 0.0101, released 2015-01-11.
+Version 0.0102, released 2015-01-11.
 
 =head1 SOURCE
 
