@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
 # PODNAME: CairoX::Sweet::Core::Point
-# ABSTRACT: Short intro
+# ABSTRACT:
 
 class CairoX::Sweet::Core::Point using Moose {
 
@@ -19,7 +19,7 @@ class CairoX::Sweet::Core::Point using Moose {
         isa => Num,
         required => 1,
     );
-    
+
     method out {
         return ($self->x, $self->y);
     }
@@ -37,11 +37,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Core::Point - Short intro
+CairoX::Sweet::Core::Point - class CairoX::Sweet::Core::Point using Moose {
 
 =head1 VERSION
 
-Version 0.0101, released 2015-01-11.
+Version 0.0102, released 2015-01-11.
 
 =head1 SOURCE
 
