@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
 # PODNAME: CairoX::Sweet::Path
-# ABSTRACT: Handles a path
+# ABSTRACT:
 
 class CairoX::Sweet::Path using Moose {
 
@@ -148,11 +148,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Path - Handles a path
+CairoX::Sweet::Path - class CairoX::Sweet::Path using Moose {
 
 =head1 VERSION
 
-Version 0.0101, released 2015-01-11.
+Version 0.0102, released 2015-01-11.
 
 =head1 SYNOPSIS
 
@@ -160,7 +160,7 @@ Version 0.0101, released 2015-01-11.
 
     my $c = CairoX::Sweet->new(500, 500, '#ffffff');
     my $path = CairoX::Sweet::Path->new(start => [35, 50], color => '#8855bb', width => 10, cap => 'round', join => 'round');
-    
+
     $path->add_relative_line(qw/
         20 -5
         10 0
@@ -211,7 +211,7 @@ A number. Optional. Sets the pen width.
 
 =head2 cap => cap_type
 
-One of C<butt>, C<round> or C<square>. 
+One of C<butt>, C<round> or C<square>.
 
 =head2 join => join_type
 
@@ -267,7 +267,7 @@ Moves all points in the path C<x> and C<y> points from their current positions.
 
     my $c = CairoX::Sweet->new(220, 130, background_color => '#ffffff');
     my $path = CairoX::Sweet::Path->new(start => [25, 50], color => '#8855bb', width => 10, join => 'miter');
-    
+
     $path->add_line(qw/
          45 95
          55 95
