@@ -1,6 +1,6 @@
 use 5.20.0;
 
-our $VERSION = '0.0101'; # VERSION
+our $VERSION = '0.0102'; # VERSION
 
 package CairoX::Sweet::Standard {
 
@@ -8,7 +8,6 @@ package CairoX::Sweet::Standard {
     use Types::CairoX::Sweet();
     use MooseX::StrictConstructor();
     use List::AllUtils();
-    use Eponymous::Hash();
     use Path::Tiny();
 
     sub import {
@@ -19,7 +18,6 @@ package CairoX::Sweet::Standard {
             'Types::CairoX::Sweet' => [{ replace => 1 }, '-types'],
             'MooseX::StrictConstructor' => [],
             'List::AllUtils' => [qw/any sum zip/],
-            'Eponymous::Hash' => ['eh'],
             'Path::Tiny' => ['path'],
         );
 
@@ -41,7 +39,7 @@ CairoX::Sweet::Standard
 
 =head1 VERSION
 
-Version 0.0101, released 2015-01-11.
+Version 0.0102, released 2015-01-11.
 
 =head1 SOURCE
 
